@@ -41,12 +41,16 @@ from .slot import slot
 from .opgp import openpgp
 from .oath import oath
 from .piv import piv
-import ykman.cli.logging_setup
+import ykman.logging_setup
 import usb.core
 import click
+import logging
 import sys
 
 
+logger = logging.getLogger(__name__)
+
+
 CLICK_CONTEXT_SETTINGS = dict(
     help_option_names=['-h', '--help'],
     max_content_width=999
@@ -122,18 +126,23 @@ def _run_cmd_for_single(ctx, cmd, transports):
               expose_value=False, is_eager=True)
 @click.option('-d', '--device', type=int, metavar='SERIAL')
 @click.option('-l', '--log-level', default=None,
-              type=click.Choice(ykman.cli.logging_setup.LOG_LEVEL_NAMES),
+              type=click.Choice(ykman.logging_setup.LOG_LEVEL_NAMES),
               help='Enable logging at given verbosity level',
               )
+@click.option('--log-file', default=None,
+              type=str, metavar='FILE',
+              help='Write logs to the given FILE instead of standard error; '
+                   'ignored unless --log-level is also set',
+              )
 @click.pass_context
 @click_skip_on_help
-def cli(ctx, device, log_level):
+def cli(ctx, device, log_level, log_file):
     """
     Configure your YubiKey via the command line.
     """
 
     if log_level:
-        ykman.cli.logging_setup.setup(log_level)
+        ykman.logging_setup.setup(log_level, log_file=log_file)
 
     subcmd = next(c for c in COMMANDS if c.name == ctx.invoked_subcommand)
     if subcmd == list_keys:
@@ -187,10 +196,12 @@ def main():
     try:
         cli(obj={})
     except ValueError as e:
+        logger.error('Error', exc_info=e)
         print('Error:', e)
         return 1
 
     except Cve201715361VulnerableError as err:
+        logger.error('Error', exc_info=err)
         print('Error:', err)
         return 2
 
