@@ -27,6 +27,7 @@
 
 from __future__ import absolute_import
 import click
+import logging
 from threading import Timer
 from binascii import b2a_hex, a2b_hex
 from .util import (
@@ -38,6 +39,9 @@ from ..util import TRANSPORT, parse_b32_key
 from ..oath import OathController, SW, CredentialData, OATH_TYPE, ALGO
 from ..settings import Settings
 
+
+logger = logging.getLogger(__name__)
+
 click_touch_option = click.option(
     '-t', '--touch', is_flag=True,
     help='Require touch on YubiKey to generate code.')
@@ -291,7 +295,7 @@ def list(ctx, show_hidden, oath_type, period):
     for cred in creds:
         click.echo(cred.printable_key, nl=False)
         if oath_type:
-            click.echo(', {}'.format(cred.oath_type), nl=False)
+            click.echo(', {}'.format(cred.oath_type.name), nl=False)
         if period:
             click.echo(', {}'.format(cred.period), nl=False)
         click.echo()
@@ -474,7 +478,8 @@ def ensure_validated(ctx, prompt='Enter your password', remember=False):
             try:
                 controller.validate(a2b_hex(keys[controller.id]))
                 return
-            except Exception:
+            except Exception as e:
+                logger.debug('Error', exc_info=e)
                 del keys[controller.id]
 
         # Prompt for password
